@@ -6,3 +6,9 @@ mod slab;
 
 #[cfg(feature = "smallvec")]
 mod smallvec;
+
+#[cfg(feature = "serde_json")]
+mod serde_json;
+
+#[cfg(feature = "ijson")]
+mod ijson;
